@@ -19,20 +19,6 @@ namespace astyle {
 // ASEnhancer class
 //-----------------------------------------------------------------------------
 
-/**
- * ASEnhancer constructor
- */
-ASEnhancer::ASEnhancer()
-{
-}
-
-/**
- * Destructor of ASEnhancer
- */
-ASEnhancer::~ASEnhancer()
-{
-}
-
 /**
  * initialize the ASEnhancer.
  *
