@@ -64,6 +64,9 @@ const string CodeGenerator::STY_NAME_LIN="lin";
 const string CodeGenerator::STY_NAME_SYM="opt"; //operator
 const string CodeGenerator::STY_NAME_IPL="ipl"; //interpolation
 
+vector<Diluculum::LuaFunction*> CodeGenerator::pluginChunks;
+
+
 CodeGenerator * CodeGenerator::getInstance ( OutputType type )
 {
     CodeGenerator* generator=NULL;
@@ -129,7 +132,10 @@ CodeGenerator::CodeGenerator ( highlight::OutputType type )
      baseFontSize("10"),
      lineNumber ( 0 ),
      lineNumberOffset ( 0 ),
+     currentState ( _UNKNOWN ),
+     currentKeywordClass ( 0 ),
      includeStyleDef ( false ),
+     numberCurrentLine ( false ),
      lineIndex ( 0 ),
      lastLineLength( 0 ),
      syntaxChangeIndex(UINT_MAX),
@@ -138,6 +144,8 @@ CodeGenerator::CodeGenerator ( highlight::OutputType type )
      startLineCnt( 1 ),
      startLineCntCurFile( 1 ),
      maxLineCnt ( UINT_MAX ),
+     inputFilesCnt (0),
+     processedFilesCnt (0),
      terminatingChar ( '\0' ),
      formatter ( NULL ),
      formattingEnabled ( false ),
@@ -146,6 +154,8 @@ CodeGenerator::CodeGenerator ( highlight::OutputType type )
      numberWrappedLines ( true ),
      noTrailingNewLine(false),
      resultOfHook(false),
+     lineContainedTestCase(false),
+     applySyntaxTestCase(false),
      keywordCase ( StringTools::CASE_UNCHANGED ),
      eolDelimiter ('\n'),
      outputType ( type )
@@ -160,6 +170,11 @@ CodeGenerator::~CodeGenerator()
     for ( map<string, SyntaxReader*>::iterator it=syntaxReaders.begin(); it!=syntaxReaders.end(); it++ ) {
         delete it->second;
     }
+    
+    for (unsigned int i=0; i<pluginChunks.size(); i++) {
+        delete pluginChunks[i];
+    }
+    pluginChunks.clear();
 }
 
 
@@ -361,6 +376,11 @@ void CodeGenerator::setMaxInputLineCnt ( unsigned int cnt )
     maxLineCnt = cnt;
 }
 
+void CodeGenerator::setFilesCnt ( unsigned int cnt )
+{
+    inputFilesCnt = cnt;
+}
+
 bool CodeGenerator::formattingIsPossible()
 {
     return formattingPossible;
@@ -404,6 +424,7 @@ void CodeGenerator::reset()
     printNewLines=true;
     syntaxChangeIndex = syntaxChangeLineNo = UINT_MAX;
     startLineCntCurFile = startLineCnt;
+    applySyntaxTestCase=lineContainedTestCase=false;
 }
 
 string CodeGenerator::getThemeInitError()
@@ -467,7 +488,7 @@ bool CodeGenerator::readNewLine ( string &newLine )
     return eof || ( lineNumber == maxLineCnt );
 }
 
-void CodeGenerator::matchRegex ( const string &line, State skipState, unsigned int offset)
+void CodeGenerator::matchRegex ( const string &line, State skipState)
 {
     regexGroups.clear();
     int matchBegin=0;
@@ -486,7 +507,7 @@ void CodeGenerator::matchRegex ( const string &line, State skipState, unsigned i
             groupID = ( regexElem->capturingGroup<0 ) ? cur->size()-1 : regexElem->capturingGroup;
             matchBegin =  cur->position(groupID);
             regexGroups.insert (
-                make_pair ( matchBegin + 1 + offset, ReGroup ( regexElem->open, cur->length(groupID), regexElem->kwClass, regexElem->langName ) ) );
+                make_pair ( matchBegin + 1, ReGroup ( regexElem->open, cur->length(groupID), regexElem->kwClass, regexElem->langName ) ) );
         }
     }
 }
@@ -517,6 +538,14 @@ unsigned char CodeGenerator::getInputChar()
         }
         lastLineLength=lineIndex;
         lineIndex=0;
+        
+        if (!lineContainedTestCase && applySyntaxTestCase){
+            stateTraceTest = stateTraceCurrent;
+            stateTraceCurrent.clear();
+        } 
+        
+        lineContainedTestCase=false;
+            
         matchRegex ( line );
         stateTrace.clear();
         return ( eof ) ?'\0':'\n';
@@ -550,6 +579,12 @@ State CodeGenerator::getCurrentState (State oldState)
         token= c;
         return _WS;
     }
+    
+    //TODO add control flag
+    if ( applySyntaxTestCase && ( c=='^' || c=='<') && (oldState == ML_COMMENT || oldState==SL_COMMENT)  ) {
+        token= c;
+        return _TESTPOS;
+    }
         
     // at this position the syntax change takes place
     if (lineIndex >= syntaxChangeIndex-1 || syntaxChangeLineNo < lineNumber){
@@ -585,9 +620,16 @@ SKIP_EMBEDDED:
 
             if ( regexGroups[oldIndex].state==IDENTIFIER_BEGIN || regexGroups[oldIndex].state==KEYWORD ) {
                 string reservedWord= ( currentSyntax->isIgnoreCase() ) ? StringTools::change_case ( token ) :token;
-                currentKeywordClass=currentSyntax->isKeyword ( reservedWord );
+                currentKeywordClass=currentSyntax->isKeyword ( reservedWord ); //check in lists (no regex)
+                
+                // for positional Tests; will not be used again for actual input parsing
+                // FIXME not needed?
+                if (currentKeywordClass)
+                    regexGroups[oldIndex]=ReGroup ( KEYWORD, reservedWord.size(), currentKeywordClass, "" );  
+                
                 if ( !currentKeywordClass && regexGroups[oldIndex].state==KEYWORD )
                     currentKeywordClass = regexGroups[oldIndex].kwClass;
+                 
                 return validateState(( currentKeywordClass ) ? KEYWORD : STANDARD, oldState, currentKeywordClass);
             } else {
                 return validateState(regexGroups[oldIndex].state, oldState, 0);
@@ -616,7 +658,7 @@ State CodeGenerator::validateState(State newState, State oldState, unsigned int
 
         resultOfHook = res.size()>=1;
         if (resultOfHook) {
-            State validatedState = (State)res[0].asNumber();
+            State validatedState = (State)res[0].asInteger();
             if ( validatedState== _REJECT) {
                 // proceed using only the first character of the token
                 lineIndex -= (token.length() -1);
@@ -639,6 +681,14 @@ void CodeGenerator::maskString ( ostream& ss, const string & s )
 {
     for ( unsigned int i=0; i< s.length(); i++ ) {
         ss << maskCharacter ( s[i] );
+
+        if (applySyntaxTestCase) {
+            PositionState ps(currentState, currentKeywordClass);
+            stateTraceCurrent.push_back(ps);
+            
+            if (stateTraceCurrent.size()>200) 
+                stateTraceCurrent.erase(stateTraceCurrent.begin(), stateTraceCurrent.begin() + 100 ); 
+        }
     }
 }
 
@@ -650,6 +700,7 @@ Diluculum::LuaValueList CodeGenerator::callDecorateFct(const string&token)
     params.push_back(Diluculum::LuaValue(currentState));
     params.push_back(Diluculum::LuaValue(currentKeywordClass));
     string trace(";");
+    string trace2(";");
     if (stateTrace.size()>1){
         for (size_t i=0; i<stateTrace.size()-1;i++){
             trace += std::to_string (stateTrace[i]);
@@ -665,7 +716,7 @@ Diluculum::LuaValueList CodeGenerator::callDecorateFct(const string&token)
 void CodeGenerator::printMaskedToken (bool flushWhiteSpace, StringTools::KeywordCase tcase )
 {
     if ( flushWhiteSpace )
-        flushWs();
+        flushWs(1);
     string caseToken = StringTools::change_case ( token, tcase );
     if (currentSyntax->getDecorateFct()) {
 
@@ -1033,7 +1084,7 @@ void CodeGenerator::setIndentationOptions (const vector<string>& options){
                 string styleParam = getParam(arg, "k");
                 if (styleParam.length() > 0)
                     align = atoi(styleParam.c_str());
-                else if (align == 1)
+                if (align == 1)
                     formatter->setPointerAlignment(astyle::PTR_ALIGN_TYPE);
                 else if (align == 2)
                     formatter->setPointerAlignment(astyle::PTR_ALIGN_MIDDLE);
@@ -1062,7 +1113,7 @@ void CodeGenerator::setIndentationOptions (const vector<string>& options){
                 string styleParam = getParam(arg, "W");
                 if (styleParam.length() > 0)
                     align = atoi(styleParam.c_str());
-                else if (align == 0)
+                if (align == 0)
                     formatter->setReferenceAlignment(astyle::REF_ALIGN_NONE);
                 else if (align == 1)
                     formatter->setReferenceAlignment(astyle::REF_ALIGN_TYPE);
@@ -1178,13 +1229,10 @@ void CodeGenerator::setIndentationOptions (const vector<string>& options){
             {
                 formatter->setObjCColonPaddingMode(astyle::COLON_PAD_BEFORE);
             }
-            
         }
-    
     }
 }
 
-
 LoadResult CodeGenerator::loadLanguage ( const string& langDefPath, bool embedded )
 {
 
@@ -1294,21 +1342,92 @@ bool CodeGenerator::validateInputStream()
            || magic_table[magic_index] == magic_utf8;
 }
 
+void CodeGenerator::applyPluginChunk(const string& fctName, string *result, bool *keepDefault) {
+    
+    if ( pluginChunks.size()) {
+    
+        Diluculum::LuaState luaState;
+
+        Diluculum::LuaValueList chunkParams;
+        chunkParams.push_back(currentSyntax->getDescription());
+        for (unsigned int i=0; i<pluginChunks.size(); i++) {
+            luaState.call(*pluginChunks[i], chunkParams, "format user function");
+        }
+        
+        if (luaState.globals().count(fctName)) {
+            Diluculum::LuaFunction* documentFct=new Diluculum::LuaFunction(luaState[fctName].value().asFunction());
+        
+            luaState["HL_INPUT_FILE"] = luaState["HL_PLUGIN_PARAM"] = pluginParameter;
+            luaState["HL_OUTPUT"] = outputType;
+            luaState["HL_FORMAT_HTML"]=HTML;
+            luaState["HL_FORMAT_XHTML"]=XHTML;
+            luaState["HL_FORMAT_TEX"]=TEX;
+            luaState["HL_FORMAT_LATEX"]=LATEX;
+            luaState["HL_FORMAT_RTF"]=RTF;
+            luaState["HL_FORMAT_ANSI"]=ESC_ANSI;
+            luaState["HL_FORMAT_XTERM256"]=ESC_XTERM256;
+            luaState["HL_FORMAT_TRUECOLOR"]=ESC_TRUECOLOR;
+            luaState["HL_FORMAT_SVG"]=SVG;
+            luaState["HL_FORMAT_BBCODE"]=BBCODE;
+            luaState["HL_FORMAT_PANGO"]=PANGO;
+            luaState["HL_FORMAT_ODT"]=ODTFLAT;
+            
+            Diluculum::LuaValueList params;
+            Diluculum::LuaValueMap options;
+            options[Diluculum::LuaValue("title")] =  Diluculum::LuaValue( docTitle );   
+            options[Diluculum::LuaValue("encoding")] =  Diluculum::LuaValue(encoding);   
+            options[Diluculum::LuaValue("fragment")] =  Diluculum::LuaValue(fragmentOutput);   
+            options[Diluculum::LuaValue("font")] =  Diluculum::LuaValue(getBaseFont());   
+            options[Diluculum::LuaValue("fontsize")] =  Diluculum::LuaValue(getBaseFontSize());   
+
+            params.push_back(inputFilesCnt);
+            params.push_back(processedFilesCnt);
+            params.push_back(options);
+            
+            Diluculum::LuaValueList res=luaState.call ( *documentFct, params, fctName+" call")  ;
+            if (res.size()>=1) {
+                *keepDefault=false;
+                *result = res[0].asString();
+                if (res.size()==2)
+                    *keepDefault = res[1].asBoolean();
+            }
+            delete documentFct;
+        }
+    }
+}
+
 void CodeGenerator::printHeader()
 {
-    if ( ! fragmentOutput )
-        *out << getHeader();
+    bool keepDefaultHeader=true;
+    string pluginHeader;
+    
+    processedFilesCnt++;
+    
+    applyPluginChunk("DocumentHeader", &pluginHeader, &keepDefaultHeader);
 
+    if ( ! fragmentOutput && keepDefaultHeader)
+        *out << getHeader();
+    
+    *out << pluginHeader; 
+   
     if ( !fragmentOutput || keepInjections)
         *out << currentSyntax->getHeaderInjection();
 }
 
 void CodeGenerator::printFooter()
 {
+    
+    bool keepDefaultFooter=true;
+    string pluginFooter;
+    
+    applyPluginChunk("DocumentFooter", &pluginFooter, &keepDefaultFooter);
+    
     if ( !fragmentOutput || keepInjections)
         *out << currentSyntax->getFooterInjection();
 
-    if ( ! fragmentOutput )
+    *out << pluginFooter; 
+    
+    if ( ! fragmentOutput && keepDefaultFooter )
         *out << getFooter();
 }
 
@@ -1325,6 +1444,7 @@ ParseError CodeGenerator::generateFile ( const string &inFileName,
 
     inFile=inFileName;
     outFile=outFileName;
+        
     in = ( inFileName.empty() ? &cin :new ifstream ( inFileName.c_str() ) );
 
     if ( validateInput )
@@ -1404,6 +1524,7 @@ string CodeGenerator::generateStringFromFile ( const string &inFileName )
     reset();
 
     inFile = inFileName;
+    
     in = new ifstream ( inFileName.c_str() );
     out = new ostringstream ();
 
@@ -1450,7 +1571,7 @@ void CodeGenerator::openTag ( State s )
 void CodeGenerator::closeTag ( State s )
 {
     *out << closeTags[ ( unsigned int ) s];
-    flushWs();
+    flushWs(2);
     currentState=_UNKNOWN;
 }
 
@@ -1463,7 +1584,7 @@ void CodeGenerator::openKWTag ( unsigned int kwClassID )
 void CodeGenerator::closeKWTag ( unsigned int kwClassID )
 {
     *out << closeTags.at(getStyleID ( KEYWORD, kwClassID ) );
-    flushWs();
+    flushWs(3);
     currentState=_UNKNOWN;
 }
 
@@ -1488,12 +1609,14 @@ void CodeGenerator::processRootState()
     bool eof=false,
          firstLine=true; // avoid newline before printing the first output line
 
+    applySyntaxTestCase = inFile.find("syntax_test_")!=string::npos;
+    
     if ( currentSyntax->highlightingDisabled() ) {
         string line;
         while ( getline ( *in, line ) && lineNumber < maxLineCnt ) {
             ++lineNumber;
             insertLineNumber ( !firstLine );
-            flushWs();
+            flushWs(4);
             firstLine=false;
             if (lineNumber>=startLineCntCurFile && lineNumber <=maxLineCnt)
                 maskString ( *out, line );
@@ -1569,7 +1692,8 @@ void CodeGenerator::processRootState()
             }
             insertLineNumber ( !firstLine );
             if (!firstLine || showLineNumbers) {
-                flushWs();
+                flushWs(5);
+                stateTraceCurrent.clear();
                 openTag ( STANDARD );
             }
             firstLine=false;
@@ -1713,12 +1837,15 @@ bool CodeGenerator::processNumberState()
     return eof;
 }
 
+
+
 bool CodeGenerator::processMultiLineCommentState()
 {
     int commentCount=1;
     int openDelimID=currentSyntax->getOpenDelimiterID ( token, ML_COMMENT);
     State newState=STANDARD;
     bool eof=false, exitState=false;
+    unsigned int startColumn=lineIndex - token.size() ;
     openTag ( ML_COMMENT );
     do {
         printMaskedToken (newState!=_WS );
@@ -1732,9 +1859,15 @@ bool CodeGenerator::processMultiLineCommentState()
             wsBuffer += closeTags[ML_COMMENT];
             insertLineNumber();
             wsBuffer += openTags[ML_COMMENT];
+            startColumn=0;
             break;
         case _EOF:
             eof = true;
+            break;
+        case _TESTPOS:
+            runSyntaxTestcases(token=="<" ? startColumn : lineIndex-1 );
+            printMaskedToken();
+            
             break;
         case ML_COMMENT:
 
@@ -1762,6 +1895,9 @@ bool CodeGenerator::processMultiLineCommentState()
     } while ( !exitState  &&  !eof );
 
     closeTag ( ML_COMMENT );
+    
+    stateTraceCurrent.clear();
+    
     return eof;
 }
 
@@ -1774,6 +1910,7 @@ bool CodeGenerator::processSingleLineCommentState()
 
     State newState=STANDARD;
     bool eof=false, exitState=false;
+    unsigned int startColumn = lineIndex - token.size() ;
 
     openTag ( SL_COMMENT );
     do {
@@ -1799,12 +1936,20 @@ bool CodeGenerator::processSingleLineCommentState()
         case _EOF:
             eof = true;
             break;
+        case _TESTPOS:
+            runSyntaxTestcases(token=="<" ? startColumn : lineIndex-1 );
+            printMaskedToken();
+            break;
+     
         default:
             break;
         }
     } while ( !exitState  &&  !eof );
 
     closeTag ( SL_COMMENT );
+    
+    stateTraceCurrent.clear();
+    
     return eof;
 }
 
@@ -1951,6 +2096,7 @@ bool CodeGenerator::processStringState ( State oldState )
     } while ( !exitState && !eof );
 
     closeTag ( myState );
+
     return eof;
 }
 
@@ -2052,11 +2198,11 @@ void CodeGenerator::processWsState()
         return;
     }
 
-    flushWs();
+    flushWs(6);
 
     int cntWs=0;
     lineIndex--;
-
+    PositionState ps(_WS, 0);
     while ( line[lineIndex]==' ' || line[lineIndex]=='\t' ) {
         ++cntWs;
         ++lineIndex;
@@ -2068,25 +2214,128 @@ void CodeGenerator::processWsState()
             *out << closeTags[styleID];
         }
         *out << maskWsBegin;
-        for ( int i=0; i<cntWs; i++ ) {
-              *out <<  spacer;
+        for ( int i=0; i<cntWs && applySyntaxTestCase; i++ ) {
+            *out <<  spacer;
+            stateTraceCurrent.push_back(ps);
         }
         *out << maskWsEnd;
         if ( excludeWs && styleID!=_UNKNOWN ) {
             *out << openTags[styleID];
         }
     } else {
+    
         *out << spacer; //Bugfix fehlender Space nach Strings
+        if (applySyntaxTestCase)
+            stateTraceCurrent.push_back(ps);
     }
     token.clear();
 }
 
-void CodeGenerator::flushWs()
+void CodeGenerator::flushWs(int arg)
 {
+     PositionState ps(_WS, 0);
+     //workaround condition
+     for ( size_t i=0; i<wsBuffer.size() && (arg !=2 || (arg==2 && lineIndex>1)) && applySyntaxTestCase ; i++ ) {
+        stateTraceCurrent.push_back(ps);
+     }
+     
     *out<<wsBuffer;
     wsBuffer.clear();
 }
 
+string CodeGenerator::getTestcaseName(State s, unsigned int kwClass) {
+    switch (s) {
+        
+        case STANDARD:
+            return STY_NAME_STD;
+        case STRING:
+            return STY_NAME_STR;
+        case NUMBER:
+            return STY_NAME_NUM;
+        case SL_COMMENT:
+            return STY_NAME_SLC;
+        case ML_COMMENT:
+            return STY_NAME_COM;
+        case ESC_CHAR:
+            return STY_NAME_ESC;
+        case DIRECTIVE:
+            return STY_NAME_DIR;
+        case DIRECTIVE_STRING:
+            return STY_NAME_DST;
+        case SYMBOL:
+            return STY_NAME_SYM;
+        case STRING_INTERPOLATION:
+            return STY_NAME_IPL;
+        case _WS:
+            return "ws";
+        case KEYWORD: {
+            char kwName[5] = {0};
+            snprintf(kwName, sizeof(kwName), "kw%c", ('a'+kwClass-1));
+            return string(kwName);
+        }
+        default:
+            return "unknown_test";
+    }
+}
+
+void CodeGenerator::runSyntaxTestcases(unsigned int column){
+    
+    
+    if (!stateTraceCurrent.size() /*|| lineIndex>stateTraceCurrent.size()*/)
+        return;
+    
+    unsigned int assertGroup=0;
+    size_t typeDescPos=line.find_first_not_of("\t ^", lineIndex);
+    State assertState=_UNKNOWN;
+    
+    if (!lineContainedTestCase){
+        stateTraceCurrent=stateTraceTest;
+    } 
+    
+    if (typeDescPos!=string::npos) {
+    
+        if (line.find(STY_NAME_NUM, typeDescPos)==typeDescPos)
+            assertState=NUMBER;
+        else if (line.find(STY_NAME_STR, typeDescPos)==typeDescPos)
+            assertState=STRING;
+        else if (line.find(STY_NAME_ESC, typeDescPos)==typeDescPos)
+            assertState=ESC_CHAR;
+        else if (line.find(STY_NAME_IPL, typeDescPos)==typeDescPos)
+            assertState=STRING_INTERPOLATION;
+        else if (line.find(STY_NAME_SYM, typeDescPos)==typeDescPos)
+            assertState=SYMBOL;
+        else if (line.find(STY_NAME_DIR, typeDescPos)==typeDescPos)
+            assertState=DIRECTIVE;
+        else if (line.find(STY_NAME_SLC, typeDescPos)==typeDescPos)
+            assertState=SL_COMMENT;
+        else if (line.find(STY_NAME_COM, typeDescPos)==typeDescPos)
+            assertState=ML_COMMENT;
+        else if (line.find("ws", typeDescPos)==typeDescPos)
+            assertState=_WS;
+        else if (line.find(STY_NAME_STD, typeDescPos)==typeDescPos)
+            assertState=STANDARD;
+        else if (line.find(STY_NAME_DST, typeDescPos)==typeDescPos)
+            assertState=DIRECTIVE_STRING;
+        
+        else if (line.find("kw", typeDescPos)==typeDescPos) {
+            assertState=KEYWORD;
+            if (isalpha(line[typeDescPos+2]))
+                assertGroup=line[typeDescPos+2] - 'a' +1;
+        }
+    
+        if (stateTraceCurrent[column].state != assertState || assertGroup != stateTraceCurrent[column].kwClass) {
+            ostringstream err;
+            err << inFile << " line " << lineNumber << ", column "<< column << ": got " << getTestcaseName(stateTraceCurrent[column].state, stateTraceCurrent[column].kwClass)  
+                << " instead of " << getTestcaseName(assertState, assertGroup) ;
+            failedPosTests.push_back(err.str());
+        }
+        
+    }
+    
+    lineContainedTestCase=true; 
+}
+
+
 string CodeGenerator::getNewLine()
 {
     return (printNewLines) ? newLineTag : "";
@@ -2217,6 +2466,7 @@ bool CodeGenerator::initPluginScript(const string& script)
 
         userScriptError="";
         Diluculum::LuaState ls;
+        
         ls.doFile (script);
         int listIdx=1;
 
@@ -2234,6 +2484,13 @@ bool CodeGenerator::initPluginScript(const string& script)
                     currentSyntax->addUserChunk(ls["Plugins"][listIdx]["Chunk"].value().asFunction());
                 }
             }
+            // Format plugins
+            else if (ls["Plugins"][listIdx]["Type"].value().asString()=="format") {
+                if (ls["Plugins"][listIdx]["Chunk"].value().type()==LUA_TFUNCTION) {
+                    addUserChunk(ls["Plugins"][listIdx]["Chunk"].value().asFunction());
+                }
+            }
+            
             listIdx++;
         }
     }  catch (Diluculum::LuaError &err) {
