@@ -10,28 +10,28 @@ Check installation.</source>
 Installation prüfen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="94"/>
+        <location filename="mainwindow.cpp" line="105"/>
         <source>Initialization error</source>
         <translation>Initialisierungsfehler</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="95"/>
+        <location filename="mainwindow.cpp" line="106"/>
         <source>Could not find syntax definitions. Check installation.</source>
         <translation>Syntaxdefinitionen nicht gefunden.
 Installation prüfen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="169"/>
+        <location filename="mainwindow.cpp" line="182"/>
         <source>Always at your service</source>
         <translation>Stets zu Diensten</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="184"/>
+        <location filename="mainwindow.cpp" line="209"/>
         <source>Select one or more files to open</source>
         <translation>Wähle eine oder mehrere Dateien zum Öffnen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="221"/>
+        <location filename="mainwindow.cpp" line="246"/>
         <source>Select destination directory</source>
         <translation>Wähle das Zielverzeichnis</translation>
     </message>
@@ -44,106 +44,112 @@ Installation prüfen.</translation>
         <translation type="obsolete">Konnte Tags-Informationen in %1 nicht lesen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="839"/>
-        <location filename="mainwindow.cpp" line="870"/>
+        <location filename="mainwindow.cpp" line="878"/>
+        <location filename="mainwindow.cpp" line="909"/>
         <source>Output error</source>
         <translation>Ausgabefehler</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="839"/>
+        <location filename="mainwindow.cpp" line="878"/>
         <source>Output directory does not exist!</source>
         <translation>Zielverzeichnis existert nicht!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="870"/>
+        <location filename="mainwindow.cpp" line="909"/>
         <source>You must define a style output file!</source>
         <translation>Sie müssen ein Stylesheet zur Ausgabe angeben!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="902"/>
+        <location filename="mainwindow.cpp" line="941"/>
         <source>Processing %1 (%2/%3)</source>
         <translation>Verarbeite %1 (%2/%3)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="908"/>
+        <location filename="mainwindow.cpp" line="947"/>
         <source>Language definition error</source>
         <translation>Fehler in Sprachdefinition</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="909"/>
+        <location filename="mainwindow.cpp" line="948"/>
         <source>Invalid regular expression in %1:
 %2</source>
         <translation>Ungültiger regulärer Ausdruck in %1: %2</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="913"/>
+        <location filename="mainwindow.cpp" line="952"/>
         <source>Unknown syntax</source>
         <translation>Unbekannte Syntax</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="913"/>
+        <location filename="mainwindow.cpp" line="952"/>
         <source>Could not convert %1</source>
         <translation>Konnte %1 nicht konvertieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="916"/>
+        <location filename="mainwindow.cpp" line="955"/>
         <source>Lua error</source>
         <translation>Lua Fehler</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="916"/>
+        <location filename="mainwindow.cpp" line="955"/>
         <source>Could not convert %1:
 Lua Syntax error: %2</source>
         <translation>Konnte %1 nicht konvertieren:\nLua Syntaxfehler: %2</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="989"/>
+        <location filename="mainwindow.cpp" line="1028"/>
         <source>Converted %1 files in %2 ms</source>
         <translation>%1 Dateien in %2 ms konvertiert</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1087"/>
+        <location filename="mainwindow.cpp" line="1126"/>
         <source>Conversion of &quot;%1&quot; not possible.</source>
         <translation>Konnte &quot;%1&quot; nicht konvertieren.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1087"/>
-        <location filename="mainwindow.cpp" line="1198"/>
-        <location filename="mainwindow.cpp" line="1219"/>
+        <location filename="mainwindow.cpp" line="1126"/>
+        <location filename="mainwindow.cpp" line="1244"/>
+        <location filename="mainwindow.cpp" line="1269"/>
         <source>clipboard data</source>
         <translation>Daten der Zwischenablage</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1153"/>
+        <location filename="mainwindow.cpp" line="1193"/>
         <source>%1 options</source>
         <translation>%1-Optionen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1189"/>
+        <location filename="mainwindow.cpp" line="1230"/>
+        <location filename="mainwindow.cpp" line="1236"/>
         <source>(user script)</source>
         <translation>(Benutzerskript)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1197"/>
+        <location filename="mainwindow.cpp" line="1243"/>
         <source>Preview (%1):</source>
         <translation>Vorschau (%1):</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1200"/>
+        <location filename="mainwindow.cpp" line="1246"/>
         <source>Current syntax: %1 %2</source>
         <translation>Aktuelle Syntax: %1 %2</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="1247"/>
+        <source>Current theme: %1 %2</source>
+        <translation>Farbschema: %1 %2</translation>
+    </message>
     <message>
         <source>Current syntax: %1</source>
         <translation type="vanished">Aktuelle Syntax: %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1219"/>
+        <location filename="mainwindow.cpp" line="1269"/>
         <source>Preview of &quot;%1&quot; not possible.</source>
         <translation>Vorschau von &quot;%1&quot; nicht möglich.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1459"/>
+        <location filename="mainwindow.cpp" line="1520"/>
         <source>Some plug-in effects may not be visible in the preview.</source>
         <translation>Einige Plug-In Effekte könnten in der Vorschau nicht dargestellt werden.</translation>
     </message>
@@ -152,20 +158,20 @@ Lua Syntax error: %2</source>
         <translation type="obsolete">Wählen Sie eine ctags Datei</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1256"/>
-        <location filename="mainwindow.cpp" line="1260"/>
-        <location filename="mainwindow.cpp" line="1264"/>
-        <location filename="mainwindow.cpp" line="1269"/>
+        <location filename="mainwindow.cpp" line="1306"/>
+        <location filename="mainwindow.cpp" line="1310"/>
+        <location filename="mainwindow.cpp" line="1314"/>
+        <location filename="mainwindow.cpp" line="1319"/>
         <source>Choose a style include file</source>
         <translation>Wählen Sie ein Eingabe-Stylesheet</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1274"/>
+        <location filename="mainwindow.cpp" line="1324"/>
         <source>About providing translations</source>
         <translation>Übersetzungen bereitstellen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1275"/>
+        <location filename="mainwindow.cpp" line="1325"/>
         <source>The GUI was developed using the Qt toolkit, and translations may be provided using the tools Qt Linguist and lrelease.
 The highlight.ts file for Linguist resides in the src/gui-qt subdirectory.
 The qm file generated by lrelease has to be saved in gui-files/l10n.
@@ -178,17 +184,17 @@ Die von lrelease ausgegebene qm-Datei wird in gui-files/l10n gespeichert.
 Bitte senden Sie eine Nachricht an as (at) andre-simon (dot) de, wenn Sie Probleme bei der Übersetzung haben oder wenn Sie eine Übersetzung fertiggestellt bzw. aktualisiert haben.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1333"/>
+        <location filename="mainwindow.cpp" line="1383"/>
         <source>Select one or more plug-ins</source>
         <translation>Wähle ein Plug-in</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1344"/>
+        <location filename="mainwindow.cpp" line="1394"/>
         <source>Select one or more syntax or theme scripts</source>
         <translation>Wähle ein oder mehrere Syntax- oder Themeskripte aus</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1402"/>
+        <location filename="mainwindow.cpp" line="1454"/>
         <source>Choose a plug-in input file</source>
         <translation>Wähle eine Eingabedatei für Plug-Ins aus</translation>
     </message>
@@ -196,40 +202,40 @@ Bitte senden Sie eine Nachricht an as (at) andre-simon (dot) de, wenn Sie Proble
 <context>
     <name>MainWindowClass</name>
     <message>
-        <location filename="mainwindow.ui" line="183"/>
+        <location filename="mainwindow.ui" line="180"/>
         <source>Choose the source code files you want to convert.</source>
         <translation>Wähle  Sourcecode-Dateien zur Konvertierung aus.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="189"/>
+        <location filename="mainwindow.ui" line="186"/>
         <source>Choose input files</source>
         <translation>Dateien wählen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="215"/>
+        <location filename="mainwindow.ui" line="212"/>
         <source>List of input files.</source>
         <translation>Liste der Eingabedateien.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="239"/>
+        <location filename="mainwindow.ui" line="236"/>
         <source>Remove the selected input files.</source>
         <translation>Lösche die markierten Dateien aus der Eingabeliste.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="242"/>
-        <location filename="mainwindow.ui" line="556"/>
+        <location filename="mainwindow.ui" line="239"/>
+        <location filename="mainwindow.ui" line="553"/>
         <location filename="mainwindow.ui" line="689"/>
         <source>Clear selection</source>
         <translation>Auswahl entfernen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="249"/>
+        <location filename="mainwindow.ui" line="246"/>
         <source>Remove all input files.</source>
         <translation>Lösche  die Eingabeliste.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="252"/>
-        <location filename="mainwindow.ui" line="566"/>
+        <location filename="mainwindow.ui" line="249"/>
+        <location filename="mainwindow.ui" line="563"/>
         <location filename="mainwindow.ui" line="699"/>
         <source>Clear all</source>
         <translation>Alle entfernen</translation>
@@ -239,18 +245,18 @@ Bitte senden Sie eine Nachricht an as (at) andre-simon (dot) de, wenn Sie Proble
         <translation type="obsolete">Zielverzeichnis</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="291"/>
+        <location filename="mainwindow.ui" line="288"/>
         <source>Output directory</source>
         <translation>Zielverzeichnis</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="310"/>
+        <location filename="mainwindow.ui" line="307"/>
         <source>Select the output directory.</source>
         <translation>Wähle das Ausgabeverzeichnis.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="313"/>
-        <location filename="mainwindow.ui" line="643"/>
+        <location filename="mainwindow.ui" line="310"/>
+        <location filename="mainwindow.ui" line="640"/>
         <location filename="mainwindow.ui" line="1286"/>
         <location filename="mainwindow.ui" line="1555"/>
         <location filename="mainwindow.ui" line="1663"/>
@@ -259,12 +265,12 @@ Bitte senden Sie eine Nachricht an as (at) andre-simon (dot) de, wenn Sie Proble
         <translation>...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="348"/>
+        <location filename="mainwindow.ui" line="345"/>
         <source>Save output in the input file directories.</source>
         <translation>Speichere Ausgabe in den Verzeichnissen der Eingabedateien.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="351"/>
+        <location filename="mainwindow.ui" line="348"/>
         <source>Write to source directories</source>
         <translation>In Quellverzeichnisse schreiben</translation>
     </message>
@@ -400,14 +406,14 @@ Entfernt den Unicode BOM.</translation>
         <translation>Höhe:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2059"/>
+        <location filename="mainwindow.ui" line="2103"/>
         <source>Reformat and indent your code.
 This feature is enabled for C, C++, C# and Java code.</source>
         <translation>Formatiere den Eingabecode.
 Diese Funktion kann auf C, C++, C# und Java-Code angewandt werden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2384"/>
+        <location filename="mainwindow.ui" line="2431"/>
         <source>&amp;Plug-Ins</source>
         <translation>&amp;Plug-Ins</translation>
     </message>
@@ -775,37 +781,37 @@ Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
         <translation>Stylesheet-Datei:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="276"/>
+        <location filename="mainwindow.ui" line="273"/>
         <source>Output destination:</source>
         <translation>Zielverzeichnis:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="332"/>
+        <location filename="mainwindow.ui" line="329"/>
         <source>Browse output directory</source>
         <translation>Öffne das Ausgabeverzeichnis</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="484"/>
+        <location filename="mainwindow.ui" line="481"/>
         <source>Paste code from clipboard and copy the output back in one step</source>
         <translation>Füge Text aus der Zwischenablage ein und kopiere die formatierte Ausgabe in einem Schritt wieder zurück</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="490"/>
+        <location filename="mainwindow.ui" line="487"/>
         <source>Paste, Convert and Copy</source>
         <translation>Einfügen, konvertieren und kopieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="657"/>
+        <location filename="mainwindow.ui" line="654"/>
         <source>Scripts</source>
         <translation>Skripte</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="663"/>
+        <location filename="mainwindow.ui" line="660"/>
         <source>Choose a custom syntax or theme script.</source>
         <translation>Wähle ein eigenes Syntax- oder Themeskript.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="666"/>
+        <location filename="mainwindow.ui" line="663"/>
         <source>Add custom script to pool</source>
         <translation>Füge Skript zur Sammlung hinzu</translation>
     </message>
@@ -874,49 +880,49 @@ Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
         <translation>Highlight</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="177"/>
+        <location filename="mainwindow.ui" line="174"/>
         <source>Files</source>
         <translation>Dateien</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="438"/>
+        <location filename="mainwindow.ui" line="435"/>
         <source>Paste clipboard content into the preview window.</source>
         <translation>Füge Inhalt der Zwischenablage in die Vorschau ein.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="441"/>
+        <location filename="mainwindow.ui" line="438"/>
         <source>Paste from clipboard (%1)</source>
         <oldsource>Paste from clipboard</oldsource>
         <translation>Aus Zwischenablage einfügen (%1)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="458"/>
+        <location filename="mainwindow.ui" line="455"/>
         <source>Copy highlighted code into the clipboard.</source>
         <translation>Kopiere formatierte Ausgabe in die Zwischenablage.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="461"/>
+        <location filename="mainwindow.ui" line="458"/>
         <source>Copy preview to clipboard (%1)</source>
         <oldsource>Copy preview to clipboard</oldsource>
         <translation>In Zwischenablage kopieren (%1)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="422"/>
+        <location filename="mainwindow.ui" line="419"/>
         <source>Select syntax:</source>
         <translation>Syntax wählen:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="429"/>
+        <location filename="mainwindow.ui" line="426"/>
         <source>Select the correct syntax of the code snippet.</source>
         <translation>Wähle die zum Text passende Syntax.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="515"/>
+        <location filename="mainwindow.ui" line="512"/>
         <source>Plug-ins</source>
         <translation>Plug-Ins</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="524"/>
+        <location filename="mainwindow.ui" line="521"/>
         <source>Add plug-in to pool</source>
         <translation>Füge Plug-In zur Sammlung hinzu</translation>
     </message>
@@ -1100,12 +1106,22 @@ Diese können in der Textverarbeitung gewählt werden, um zusätzlichen Text zu
         <translation>Formatierung</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2023"/>
+        <location filename="mainwindow.ui" line="2032"/>
         <source>Color theme:</source>
         <translation>Farbschema:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2045"/>
+        <location filename="mainwindow.ui" line="2064"/>
+        <source>Toggle classic theme or Base16 theme selection.</source>
+        <translation>Wechsle zwischen den klassischen und den Base16 Themes.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="2067"/>
+        <source>Base16</source>
+        <translation>Base16</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="2086"/>
         <source>Select a colour theme.</source>
         <translation>Wähle ein Farbschema.</translation>
     </message>
@@ -1116,84 +1132,84 @@ This feature is enabled tor C, C++, C# and Java code.</source>
 Diese Funktion kann auf C, C++, C# und Java-Code angewandt werden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2063"/>
+        <location filename="mainwindow.ui" line="2107"/>
         <source>Reformat:</source>
         <translation>Formatieren:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2082"/>
+        <location filename="mainwindow.ui" line="2126"/>
         <source>Choose a formatting scheme.</source>
         <translation>Wähle ein Formatierungs-Schema.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2096"/>
+        <location filename="mainwindow.ui" line="2140"/>
         <source>Change the keyword case.</source>
         <translation>Ändere die Groß- und Kleinschreibung, wenn die Eingabesyntax nicht case-sensitive ist.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2099"/>
+        <location filename="mainwindow.ui" line="2143"/>
         <source>Keyword case:</source>
         <translation>Schlüsselwort Case:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2118"/>
+        <location filename="mainwindow.ui" line="2162"/>
         <source>Select a keyword case.</source>
         <translation>Wähle einen Typ der Groß- und Kleinschreibung.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2122"/>
+        <location filename="mainwindow.ui" line="2169"/>
         <source>UPPER</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2127"/>
+        <location filename="mainwindow.ui" line="2174"/>
         <source>lower</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2132"/>
+        <location filename="mainwindow.ui" line="2179"/>
         <source>Capitalize</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2150"/>
+        <location filename="mainwindow.ui" line="2197"/>
         <source>Tab width:</source>
         <translation>Tabulatorbreite:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2166"/>
+        <location filename="mainwindow.ui" line="2213"/>
         <source>Enter the number of spaces which replace a tab.
 Set the width to 0 to keep tabs.</source>
         <translation>Gib die Anzahl der Leerzeichen an, die ein Tab ersetzen.
 Setze die Anzahl auf Null, um Tabs auszugeben.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2181"/>
+        <location filename="mainwindow.ui" line="2228"/>
         <source>Enable line wrapping.</source>
         <translation>Aktiviere den automatischen Zeilenumbruch.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2184"/>
+        <location filename="mainwindow.ui" line="2231"/>
         <source>Line wrapping</source>
         <translation>Zeilenumbruch</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2197"/>
+        <location filename="mainwindow.ui" line="2244"/>
         <source>Enter the maximum line length.</source>
         <translation>Gib die maximale Zeilenlänge ein.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2216"/>
+        <location filename="mainwindow.ui" line="2263"/>
         <source>Indent statements and function parameters after wrapping.</source>
         <translation>Rücke Kommandos und Funktionsparameter nach dem Umbruch ein.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2219"/>
+        <location filename="mainwindow.ui" line="2266"/>
         <source>Intelligent wrapping</source>
         <translation>Intelligenter Umbruch</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2240"/>
+        <location filename="mainwindow.ui" line="2287"/>
         <source>Font na&amp;me:</source>
         <oldsource>Font name:</oldsource>
         <translation>Schriftart:</translation>
@@ -1207,18 +1223,18 @@ Setze die Anzahl auf Null, um Tabs auszugeben.</translation>
         <translation type="vanished">Schriftgröße:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2295"/>
+        <location filename="mainwindow.ui" line="2342"/>
         <source>Enter the font size.</source>
         <translation>Gib die Schriftgröße ein.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2368"/>
+        <location filename="mainwindow.ui" line="2415"/>
         <source>&amp;Visit andre-simon.de</source>
         <oldsource>Visit andre-simon.de</oldsource>
         <translation>&amp;Besuche andre-simon.de</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2379"/>
+        <location filename="mainwindow.ui" line="2426"/>
         <source>&amp;Dock floating panels</source>
         <translation>&amp;Schwebende Fenster andocken</translation>
     </message>
@@ -1232,48 +1248,48 @@ Setze die Anzahl auf Null, um Tabs auszugeben.</translation>
         <translation type="obsolete">Website aufrufen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="386"/>
+        <location filename="mainwindow.ui" line="383"/>
         <source>Start the conversion of your input files.</source>
         <translation>Starte die Konvertierung der Eingabedateien.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="389"/>
+        <location filename="mainwindow.ui" line="386"/>
         <source>Convert files</source>
         <translation>Konvertieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="399"/>
+        <location filename="mainwindow.ui" line="396"/>
         <source>Copy highlighted code of the seleted file into the clipboard.</source>
         <translation>Kopiere den Inhalt der ausgewählten Datei mit Highlighting in die Zwischenablage.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="414"/>
+        <location filename="mainwindow.ui" line="411"/>
         <source>Clipboard</source>
         <translation>Zwischenablage</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="402"/>
+        <location filename="mainwindow.ui" line="399"/>
         <source>Copy file to clipboard</source>
         <translation>Datei in Zwischenablage</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="521"/>
+        <location filename="mainwindow.ui" line="518"/>
         <source>Choose a plug-in script.</source>
         <translation>Wähle ein Plug-In Skript aus.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="535"/>
+        <location filename="mainwindow.ui" line="532"/>
         <source>List of plug-ins. Toggle checkbox to enable the scripts. The preview window may not display all plug-in effects.</source>
         <oldsource>List of plug-ins. Toggle checkbox to enable the scripts.</oldsource>
         <translation>Liste der Plug-Ins. Klicke auf die Checkboxen um Skripte zu aktivieren. Die Vorschau zeigt möglicherweise nicht alle Effekte an.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="553"/>
+        <location filename="mainwindow.ui" line="550"/>
         <source>Remove the selected plug-ins.</source>
         <translation>Entferne ausgewählte Plug-Ins aus der Liste.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="563"/>
+        <location filename="mainwindow.ui" line="560"/>
         <source>Remove all plug-ins.</source>
         <translation>Entferne alle Plug-Ins.</translation>
     </message>
@@ -1313,35 +1329,35 @@ Setze die Anzahl auf Null, um Tabs auszugeben.</translation>
         <translation type="vanished">Sie können die System-Tastenkombinationen zum Kopieren und Einfügen verwenden.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="575"/>
+        <location filename="mainwindow.ui" line="572"/>
         <location filename="mainwindow.ui" line="708"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="587"/>
+        <location filename="mainwindow.ui" line="584"/>
         <source>Shows decription of a selected plug-in script.</source>
         <translation>Zeigt Beschreibung des ausgewählten Plug-In Skripts.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="590"/>
+        <location filename="mainwindow.ui" line="587"/>
         <source>Plug-In description</source>
         <translation>Plug-In Beschreibung</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="618"/>
+        <location filename="mainwindow.ui" line="615"/>
         <source>Plug-in parameter</source>
         <oldsource>Plug-in input file</oldsource>
         <translation>Plug-In Parameter</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="627"/>
+        <location filename="mainwindow.ui" line="624"/>
         <source>Optional plug-in parameter, this may be a path to a plug-in input file</source>
         <oldsource>Optional path to a plug-in input file</oldsource>
         <translation>Optionaler Parameter, dies kann ein Pfad zu einer Eingabedatei sein</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="640"/>
+        <location filename="mainwindow.ui" line="637"/>
         <source>Select the plug-in input file.</source>
         <translation>Wähle eine Plug-In Eingabedatei.</translation>
     </message>
@@ -1355,78 +1371,78 @@ Setze die Anzahl auf Null, um Tabs auszugeben.</translation>
         <translation type="obsolete">Benutze geschützte Leerzeichen</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2226"/>
+        <location filename="mainwindow.ui" line="2273"/>
         <source>Do not add line numbering to lines which were automatically wrapped.</source>
         <translation>Gib bei automatisch umgebrochenen Zeilen keine Nummerierung aus.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2229"/>
+        <location filename="mainwindow.ui" line="2276"/>
         <source>Omit line numbers of wrapped lines</source>
         <translation>Keine Nummerierung bei Umbruch</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2261"/>
+        <location filename="mainwindow.ui" line="2308"/>
         <source>Select or enter the font name. HTML supports a list of fonts, separated with comma.</source>
         <translation>Wähle oder gib den Fontnamen ein. HTML unterstützt auch eine mit Komma getrennte Liste von Fonts.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2273"/>
+        <location filename="mainwindow.ui" line="2320"/>
         <source>Font si&amp;ze:</source>
         <translation>Schrift&amp;größe:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2310"/>
+        <location filename="mainwindow.ui" line="2357"/>
         <source>&amp;Open files</source>
         <translation>Öffne &amp;Dateien</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2315"/>
+        <location filename="mainwindow.ui" line="2362"/>
         <source>&amp;Exit</source>
         <translation>&amp;Beenden</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2320"/>
+        <location filename="mainwindow.ui" line="2367"/>
         <source>&amp;Load</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2325"/>
+        <location filename="mainwindow.ui" line="2372"/>
         <source>&amp;Save</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2330"/>
+        <location filename="mainwindow.ui" line="2377"/>
         <source>Load &amp;default project</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2335"/>
+        <location filename="mainwindow.ui" line="2382"/>
         <source>&amp;Readme</source>
         <oldsource>Readme</oldsource>
         <translation>&amp;Handbuch</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2340"/>
+        <location filename="mainwindow.ui" line="2387"/>
         <source>&amp;Tips</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2348"/>
+        <location filename="mainwindow.ui" line="2395"/>
         <source>&amp;Changelog</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2353"/>
+        <location filename="mainwindow.ui" line="2400"/>
         <source>&amp;License</source>
         <translation>&amp;Lizenz</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2358"/>
+        <location filename="mainwindow.ui" line="2405"/>
         <source>&amp;About Highlight</source>
         <translation>&amp;Über Highlight</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="2363"/>
+        <location filename="mainwindow.ui" line="2410"/>
         <source>A&amp;bout translations</source>
         <oldsource>About &amp;translations</oldsource>
         <translation>&amp;Infos zu Übersetzungen</translation>
