@@ -67,7 +67,7 @@ MainWindow::MainWindow(QWidget *parent)
     // fill themes combo
 
 #ifdef Q_OS_OSX
-    QDir themesDir(QCoreApplication::applicationDirPath() + "/../Resources/themes");
+    QDir themesDirClassic(QCoreApplication::applicationDirPath() + "/../Resources/themes");
     QDir themesDirBase16(QCoreApplication::applicationDirPath() + "/../Resources/themes/base16");
 
 #else
@@ -114,6 +114,7 @@ MainWindow::MainWindow(QWidget *parent)
         ui->pbLATEXChooseStyleIncFile->setMaximumWidth(30);
         ui->pbTEXChooseStyleIncFile->setMaximumWidth(30);
         ui->pbSVGChooseStyleIncFile->setMaximumWidth(30);
+        ui->tabIOSelection->setDocumentMode(false);
     #endif
 
     QObject::connect(ui->pbOpenFiles, SIGNAL(clicked()), this, SLOT(openFiles()));
@@ -420,7 +421,7 @@ void MainWindow::writeSettings()
     settings.setValue(ui->sbLineNoWidth->property(name).toString(),
                       ui->sbLineNoWidth->value());
     settings.setValue(ui->sbLineNoStart->property(name).toString(),
-                      ui->sbLineNoStart->value());    
+                      ui->sbLineNoStart->value());
     settings.setValue(ui->tabWidgetOptions->property(name).toString(),
                       ui->tabWidgetOptions->currentIndex());
 
@@ -791,6 +792,8 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
     generator->setPrintZeroes(ui->cbPadZeroes->isEnabled() && ui->cbPadZeroes->isChecked());
     generator->setPluginParameter(ui->lePluginReadFilePath->text().toStdString());
     generator->setOmitVersionComment(ui->cbHTMLPasteMIME->isChecked() || ui->cbOmitVersionInfo->isChecked());
+    
+    generator->setFilesCnt( previewMode ? 1 :  ui->lvInputFiles->count() );
 
     QString themePath=getUserScriptPath("theme");
 
@@ -933,7 +936,7 @@ void MainWindow::on_pbStartConversion_clicked()
     QString lastStyleDestDir;
     QSet<QString> usedFileNames;
 
-    QStringList inputErrors, outputErrors, reformatErrors;
+    QStringList inputErrors, outputErrors, reformatErrors, syntaxTestErrors;
 
     for (int i=0; i<ui->lvInputFiles->count(); i++) {
         inFilePath =  ui->lvInputFiles->item(i)->data(Qt::UserRole).toString();
@@ -1026,17 +1029,24 @@ void MainWindow::on_pbStartConversion_clicked()
         }
     }
 
+    vector<string> posTestErrors = generator->getPosTestErrors();
+    for (vector<string>::iterator it=posTestErrors.begin(); it!=posTestErrors.end(); it++ ) {
+           syntaxTestErrors.append(QString::fromStdString(*it));
+    }
+
     statusBar()->showMessage(tr("Converted %1 files in %2 ms").arg(ui->lvInputFiles->count()).arg(t.elapsed()));
     ui->progressBar->reset();
     this->setCursor(Qt::ArrowCursor);
     ui->pbStartConversion->setEnabled(true);
     ui->pbCopyFile2CP->setEnabled(true);
 
-    if (!inputErrors.isEmpty() || !outputErrors.isEmpty() || !reformatErrors.isEmpty()) {
+    if (!inputErrors.isEmpty() || !outputErrors.isEmpty() || !reformatErrors.isEmpty() || !syntaxTestErrors.isEmpty()) {
         io_report report;
         report.addInputErrors(inputErrors);
         report.addOutputErrors(outputErrors);
         report.addReformatErrors(reformatErrors);
+        report.addSyntaxTestErrors(syntaxTestErrors);
+
         report.exec();
         if (report.removeInputErrorFiles()) {
 
