@@ -372,6 +372,9 @@ public:
     /** \param cnt upper limit of input lines to be processed */
     void setMaxInputLineCnt ( unsigned int cnt );
 
+    /** \param cnt number of input files */
+    void setFilesCnt ( unsigned int cnt );
+
     /** \param keyCase Keyword case */
     void setKeyWordCase ( StringTools::KeywordCase keyCase );
 
@@ -406,6 +409,8 @@ public:
     /** \return Theme description */
     string getThemeDescription();
 
+    vector<string> getPosTestErrors() { return failedPosTests; }
+    
     /** \return Pointer Syntaxreader, intended for debug output  */
     SyntaxReader* getSyntaxReader()
     {
@@ -617,7 +622,7 @@ protected:
     unsigned int getLastLineLength();
     
     /** print all remaining white space*/
-    void flushWs();
+    void flushWs(int );
 
     /** \return Content of user defined input style */
     string readUserStyleDef();
@@ -752,6 +757,11 @@ private:
     /**maximum count of input lines to be processed*/
     unsigned int maxLineCnt;
     
+    
+    /**number of files to be processed and counter*/
+    unsigned int inputFilesCnt;
+    unsigned int processedFilesCnt;
+    
     /**last character of the last line*/
     unsigned char terminatingChar;
 
@@ -775,6 +785,10 @@ private:
 
     /** indicator if current state was set by Lua hook function */
     bool resultOfHook;
+    
+    bool lineContainedTestCase;
+    
+    bool applySyntaxTestCase;
 
     /** flag which determines keyword output (unchangeed, uppercase, lowercase)*/
     StringTools::KeywordCase keywordCase;
@@ -820,9 +834,14 @@ private:
     bool processSymbolState();                ///< process symbols
     void processWsState();                    ///< process whitespace
     bool processSyntaxChangeState(State myState ); ///< process syntax change of embedded languages
-
+    
+    /* checks whether the given state was defined in the same column of the last parsed input line */
+    void runSyntaxTestcases(unsigned int column);
+    
+    /* returns name of testcase state */
+    string getTestcaseName(State s, unsigned int kwClass);
+    
     /** print escaped token and clears it
-
        \param flushWhiteSpace set true if white space should be flushed
        \param tcase keyword case
     */
@@ -831,14 +850,28 @@ private:
 
     /** association of matched regexes and the corresponding keyword class ids*/
     map <int, ReGroup> regexGroups;
+    
+    /** history of states per line position in the current line of input code (max 200 entries) */
+    
+    struct PositionState {
+        State state;
+        unsigned int kwClass;
+        PositionState(const State s, const unsigned int kwc)
+        : state(s), kwClass(kwc){
+            if (s!=KEYWORD) kwClass=0;
+        }
+    };
+    vector<PositionState> stateTraceCurrent, stateTraceTest;
 
+    vector<string> failedPosTests; 
+    
     /** association of syntax definitions and their paths*/
     map <string, SyntaxReader*> syntaxReaders;
 
     /** test for regular expressions
         \param line current input line
         \param skipState state which should be ignored*/
-    void matchRegex ( const string &line, State skipState=_UNKNOWN, unsigned int offset=0 );
+    void matchRegex ( const string &line, State skipState=_UNKNOWN );
 
     /** \return true if input is no binary stream */
     bool validateInputStream();
@@ -861,6 +894,18 @@ private:
     bool isOption(const string& arg, const char* op1, const char* op2);
     bool isParamOption(const string& arg, const char* option);
     bool isParamOption(const string& arg, const char* option1, const char* option2);
+  
+    /**
+    	\param chunk Lua function to be added to the function list
+    */
+    void addUserChunk(const Diluculum::LuaFunction& chunk)
+    {
+        pluginChunks.push_back(new Diluculum::LuaFunction(chunk));
+    }
+    
+    void applyPluginChunk(const string& fctName, string *result, bool *keepDefault);
+    
+    static vector<Diluculum::LuaFunction*> pluginChunks;
     
     /** \deprecated replace by Lua functionality */
     bool checkSpecialCmd();
